import { connect, Dispatch } from 'react-redux';
import {
  InfraDetail,
  StateProps as InfraDetailStateProps,
  DispatchProps as InfraDetailDispatchProps,
} from './components/InfraDetail';

import MetaInfraType from '@overflow/meta/api/model/MetaInfraType';
import * as ReadActions from '../redux/action/read';
import * as asyncRequestActions from '@overflow/commons/redux/action/asyncRequest';

export function mapStateToProps(state: any, props: any): InfraDetailStateProps {
  return {
    infra: props.infra,
    machine: state.machine,
    host: state.host,
    os: state.os,
    osApplication: state.osApplication,
    osDaemon: state.osDaemon,
    osPort: state.osPort,
    service: state.service,
  };
}

export function mapDispatchToProps(dispatch: Dispatch<any>): InfraDetailDispatchProps {
  return {
    onReadInfraMachine: (id: string) => {
      dispatch(asyncRequestActions.request('InfraMachineService', 'read', ReadActions.REQUEST, id));
    },
    onReadInfraHost: (id: string) => {
      dispatch(asyncRequestActions.request('InfraHostService', 'read', ReadActions.REQUEST, id));
    },
    onReadInfraOS: (id: string) => {
      dispatch(asyncRequestActions.request('InfraOSService', 'read', ReadActions.REQUEST, id));
    },
    onReadInfraOSApplication: (id: string) => {
      dispatch(asyncRequestActions.request('InfraOSApplicationService', 'read', ReadActions.REQUEST, id));
    },
    onReadInfraOSDaemon: (id: string) => {
      dispatch(asyncRequestActions.request('InfraOSDaemonService', 'read', ReadActions.REQUEST, id));
    },
    onReadInfraOSPort: (id: string) => {
      dispatch(asyncRequestActions.request('InfraOSPortService', 'read', ReadActions.REQUEST, id));
    },
    onReadInfraService: (id: string) => {
      dispatch(asyncRequestActions.request('InfraServiceService', 'read', ReadActions.REQUEST, id));
    },
  };
}



export default connect(mapStateToProps, mapDispatchToProps)(InfraDetail);
