import * as React from 'react';
import { Button, Table, Header, Container } from 'semantic-ui-react';
import { SensorList } from '@overflow/sensor/react/components/SensorList';
import { DetailContainer } from '@overflow/commons/react/component/DetailContainer';

import Target from '@overflow/target/api/model/Target';
import MetaInfraType from '@overflow/meta/api/model/MetaInfraType';
import Infra from '@overflow/infra/api/model/Infra';
import InfraHost from '@overflow/infra/api/model/InfraHost';
import InfraMachine from '@overflow/infra/api/model/InfraMachine';
import InfraOS from '@overflow/infra/api/model/InfraOS';
import InfraOSApplication from '@overflow/infra/api/model/InfraOSApplication';
import InfraOSDaemon from '@overflow/infra/api/model/InfraOSDaemon';
import InfraOSPort from '@overflow/infra/api/model/InfraOSPort';
import InfraService from '@overflow/infra/api/model/InfraService';

import * as Utils from '@overflow/commons/util/Utils';

export interface StateProps {
  infra?: Infra;
  // children of Infra
  machine?: InfraMachine;
  host?: InfraHost;
  os?: InfraOS;
  osApplication?: InfraOSApplication;
  osDaemon?: InfraOSDaemon;
  osPort?: InfraOSPort;
  service?: InfraService;
}

export interface DispatchProps {
  onReadInfraMachine?(id: string): void;
  onReadInfraHost?(id: string): void;
  onReadInfraOS?(id: string): void;
  onReadInfraOSApplication?(id: string): void;
  onReadInfraOSDaemon?(id: string): void;
  onReadInfraOSPort?(id: string): void;
  onReadInfraService?(id: string): void;
}


export type Props = StateProps & DispatchProps;

export interface State {
}

export class InfraDetail extends React.Component<Props, State> {

  constructor(props: Props, context: State) {
    super(props, context);
    this.state = {
    };
  }

  public componentWillMount(): void {
    let infraType = this.props.infra.infraType.id;
    let id = String(this.props.infra.childId);
    switch (infraType) {
      case 1: {
        this.props.onReadInfraMachine(id);
        break;
      }
      case 2: {
        this.props.onReadInfraHost(id);
        break;
      }
      case 3: {
        this.props.onReadInfraOS(id);
        break;
      }
      case 4: {
        this.props.onReadInfraOSApplication(id);
        break;
      }
      case 5: {
        this.props.onReadInfraOSDaemon(id);
        break;
      }
      case 6: {
        this.props.onReadInfraOSPort(id);
        break;
      }
      case 7: {
        this.props.onReadInfraService(id);
        break;
      }
      default: {
        break;
      }
    }
  }

  public handleRemoveTarget(): void {
    alert('remove');
  }

  public render(): JSX.Element {
    if (this.props.machine === undefined
      && this.props.host === undefined
      && this.props.os === undefined
      && this.props.osApplication === undefined
      && this.props.osDaemon === undefined
      && this.props.osPort === undefined
      && this.props.service === undefined
    ) {
      return null;
    }
    let infraType = this.props.infra.infraType.id;
    let child = null;
    switch (infraType) {
      case 1: {
        child = <InfraTable tableDatas={this.ConvertTableDataForMachine(this.props.machine)} />;
        break;
      }
      case 2: {
        child = <InfraTable tableDatas={this.ConvertTableDataForHost(this.props.host)} />;
        break;
      }
      case 3: {
        // this.props.onReadInfraOS(id);
        break;
      }
      case 4: {
        // this.props.onReadInfraOSApplication(id);
        break;
      }
      case 5: {
        // this.props.onReadInfraOSDaemon(id);
        break;
      }
      case 6: {
        // this.props.onReadInfraOSPort(id);
        break;
      }
      case 7: {
        // this.props.onReadInfraService(id);
        break;
      }
      default: {
        break;
      }
    }

    return (
      <Container fluid>
        {child}
      </Container>
    );
  }

  private ConvertTableDataForHost(infraChild: InfraHost): Array<TableData> {
    let NewTableDatas: Array<TableData>;

    NewTableDatas = [{
      header: 'IP',
      contents: Utils.int2ip(infraChild.ip),
    },
    {
      header: 'MAC',
      contents: Utils.intToMac(infraChild.mac),
    },
    ];

    return NewTableDatas;
  }

  private ConvertTableDataForMachine(infraChild: InfraMachine): Array<TableData> {

    let NewTableDatas: Array<TableData>;

    NewTableDatas = [{
      header: 'Meta',
      contents: infraChild.meta,
    },
    ];

    return NewTableDatas;
  }

  private ConvertTableDataForOS(infraChild: InfraOS): Array<TableData> {

    let NewTableDatas: Array<TableData>;

    NewTableDatas = [
      {
        header: 'Meta',
        contents: infraChild.meta,
      },
      {
        header: 'Vendor',
        contents: infraChild.vendor.name,
      },
    ];

    return NewTableDatas;
  }


}

export interface TableData {
  header: string;
  contents: any;
}

export interface InfraTableProps {
  tableDatas: Array<TableData>;
}

export class InfraTable extends React.Component<InfraTableProps, any> {
  constructor(props: InfraTableProps, context: any) {
    super(props, context);
    this.state = {
    };
  }

  public showInfra(): JSX.Element[] {
    let elems: Array<JSX.Element> = new Array();
    let i = 0;
    for (let data of this.props.tableDatas) {
      elems.push(
        <Table.Row key={i++}>
          <Table.Cell collapsing>
            <Header size='small'>{data.header}</Header>
          </Table.Cell>
          <Table.Cell>
            {data.contents}
          </Table.Cell>
        </Table.Row>,
      );
    }

    return elems;
  }

  public render(): JSX.Element {
    return (
      <Table celled={false}>
        <Table.Body>
          {this.showInfra()}
        </Table.Body>
      </Table>
    );
  }
}

