import * as React from 'react';
import {
  Table,
  Checkbox,
  Button,
  Header,
  Container,
} from 'semantic-ui-react';
import NoAuthProbe from '@overflow/noauthprobe/api/model/NoAuthProbe';
import Domain from '@overflow/domain/api/model/Domain';
import { ListContainer } from '@overflow/commons/react/component/ListContainer';
import * as Utils from '@overflow/commons/util/Utils';
export interface StateProps {
  noauthList?: NoAuthProbe[];
}

export interface DispatchProps {
  onReadAllByDomain?(domain: Domain):void;
  registNoAuthProbe?(noauthProbe: NoAuthProbe[]):void;
}

export type Props = StateProps & DispatchProps;

export interface State {
  selected: NoAuthProbe[];
  list: NoAuthProbe[];
}

export class NoauthProbeList extends React.Component<Props, State> {

  private data: any;
  private selectedIds: NoAuthProbe[];

  constructor(props: Props, context: State) {
    super(props, context);
    this.state = {
      selected: [],
      list: null,
    };
    this.selectedIds = new Array();
  }

  public componentWillMount(): void {
    let domain: Domain = {
      id:1,
    };
    this.props.onReadAllByDomain(domain);
  }

  public handleSelect(probe: NoAuthProbe): void {
    let idx = this.selectedIds.indexOf(probe);
    if (idx === -1) {
      this.selectedIds.push(probe);
    } else {
      this.selectedIds.splice(idx, 1);
    }
    this.setState({
      selected: this.selectedIds,
    });
  }

  public handleSearch = (result: any[]): void => {
    this.setState({
      list: result,
    });
  }

  public checkExist(probe: NoAuthProbe): boolean {
    if (this.state.selected.indexOf(probe) === -1) {
      return false;
    }
    return true;
  }

  public handleAccept(): void {
    this.props.registNoAuthProbe(this.state.selected);
  }

  public handleDeny(): void {
    alert(this.state.selected);
  }

  public handleRowActive(probe: NoAuthProbe): boolean {
    if (this.state.selected.indexOf(probe) === -1) {
      return false;
    }
    return true;
  }

  public render(): JSX.Element {
    let noauth =
      <Container fluid>
        <Table celled selectable striped>
          <Table.Header>
            <Table.Row>
              <Table.HeaderCell />
              <Table.HeaderCell textAlign={'center'}>No.</Table.HeaderCell>
              <Table.HeaderCell textAlign={'center'}>Host IP</Table.HeaderCell>
              <Table.HeaderCell textAlign={'center'}>Host Mac</Table.HeaderCell>
              <Table.HeaderCell textAlign={'center'}>Host Name</Table.HeaderCell>
              <Table.HeaderCell textAlign={'center'}>Created At</Table.HeaderCell>
              <Table.HeaderCell textAlign={'center'}>API Key</Table.HeaderCell>
            </Table.Row>
          </Table.Header>

          <Table.Body>
            {this.renderRows()}
          </Table.Body>
        </Table>
        <Button primary floated={'right'} onClick={this.handleAccept.bind(this)}>Accept</Button>
        <Button floated={'right'} onClick={this.handleDeny.bind(this)}>Deny</Button>
      </Container>;
    return (
      <ListContainer
        contents={noauth}
        data={this.props.noauthList}
        onSearch={this.handleSearch}
        filter={null}
      />
    );
  }

  private renderRows(): (JSX.Element | JSX.Element[]) {
    if (this.props.noauthList === undefined) {
      return null;
    }

    if (this.props.noauthList.length === 0) {
      return <Table.Row error >
        <Table.Cell textAlign='center' colSpan='6'>No results found.</Table.Cell>
      </Table.Row>;
    }

    return this.props.noauthList.map((probe: NoAuthProbe, index: number) => (
      <Table.Row key={index} onClick={this.handleSelect.bind(this, probe)} active={this.handleRowActive(probe)}>
        <Table.Cell collapsing>
          <Checkbox checked={this.checkExist(probe)} />
        </Table.Cell>
        <Table.Cell textAlign={'center'}>{index + 1}</Table.Cell>
        <Table.Cell textAlign={'center'}>{probe.ipAddress}</Table.Cell>
        <Table.Cell textAlign={'center'}>{probe.macAddress}</Table.Cell>
        <Table.Cell>{probe.hostName}</Table.Cell>
        <Table.Cell textAlign={'center'}>{Utils.date2date(probe.createDate)}</Table.Cell>
        <Table.Cell textAlign={'center'}>{probe.apiKey}</Table.Cell>
      </Table.Row>
    ));
  }
}

// this.data = [
//   {
//     'id': '11',
//     'MetaNoAuthProbeStatus': {
//       'name': 'PROCESS',
//     },
//     'hostName': 'insanity windows',
//     'macAddress': '14:fe:b5:9d:54:7e',
//     'ipAddress': '192.168.1.105',
//     'tempProbeKey': '45374d4egsdfw332',
//     'apiKey': '45374d4egsdfw332',
//     'domain': {
//
//     },
//     'probe': {
//
//     },
//   },
//   {
//     'id': '22',
//     'MetaNoAuthProbeStatus': {
//       'name': 'PROCESS',
//     },
//     'hostName': 'insanity ubuntu',
//     'macAddress': '14:fe:b5:9d:54:7e',
//     'ipAddress': '192.168.1.105',
//     'tempProbeKey': '45374d4egsdfw332',
//     'apiKey': '45374d4egsdfw332',
//     'domain': {
//
//     },
//     'probe': {
//
//     },
//   },
//   {
//     'id': '33',
//     'MetaNoAuthProbeStatus': {
//       'name': 'PROCESS',
//     },
//     'hostName': 'insanity ubuntu',
//     'macAddress': '14:fe:b5:9d:54:7e',
//     'ipAddress': '192.168.1.105',
//     'tempProbeKey': '45374d4egsdfw332',
//     'apiKey': '45374d4egsdfw332',
//     'domain': {
//
//     },
//     'probe': {
//
//     },
//   },
// ];

